/*! @name @viostream/videojs-share-menu @version v0.0.11 @license MIT */
import videojs$1 from 'video.js';
import _assertThisInitialized from '@babel/runtime/helpers/assertThisInitialized';
import _inheritsLoose from '@babel/runtime/helpers/inheritsLoose';

var version = "v0.0.11";

/* eslint-disable no-undef */
var Component$3 = videojs.getComponent('Component');
/**
  * The class for Download Button
  *
  * @extends Component
  */

var DownloadButtonControl = /*#__PURE__*/function (_Component) {
  _inheritsLoose(DownloadButtonControl, _Component);

  /**
   * Constructor for class
   *
   * @param {Player|Object} player The player
   * @param {options|Object} options player options
   */
  function DownloadButtonControl(player, options) {
    var _this;

    _this = _Component.call(this, player, options) || this;

    if (!options.downloadButton) {
      return _assertThisInitialized(_this);
    }

    if (options.downloadButton.showDownloadButton !== true) {
      return _assertThisInitialized(_this);
    }

    if (options.downloadButton.downloadLink === 'undefined') {
      return _assertThisInitialized(_this);
    }

    var downloadButton = _this.createEl('button', {
      className: 'vjs-share-menu-download-button vjs-share-menu-top-button',
      type: 'button'
    });

    downloadButton.setAttribute('title', 'Download Transcript');
    downloadButton.setAttribute('aria-label', 'Download Transcript');
    downloadButton.innerHTML = '<span class="vjs-icon-downloadfile"></span>';

    if (options.downloadButton.downloadTitle !== 'undefined') {
      options.downloadButton.downloadTitle;
    }

    downloadButton.addEventListener('click', function (e) {
      window.open(options.downloadButton.downloadLink, '_blank');
      player.trigger('transcript', {
        id: options.downloadButton.id
      });
      e.stopPropagation();
    });
    downloadButton.addEventListener('touchend', function (e) {
      e.stopPropagation();
    });
    _this.el_ = downloadButton;
    return _this;
  }

  return DownloadButtonControl;
}(Component$3);

/* eslint-disable no-undef */
var Component$2 = videojs.getComponent('Component');
/**
  * The class for Download Button
  *
  * @extends Component
  */

var OpenShareButtonControl = /*#__PURE__*/function (_Component) {
  _inheritsLoose(OpenShareButtonControl, _Component);

  /**
   * Constructor for class
   *
   * @param {Player|Object} player The player
   * @param {options|Object} options player options
   */
  function OpenShareButtonControl(player, options) {
    var _this;

    _this = _Component.call(this, player, options) || this;

    var openShareButton = _this.createEl('button', {
      className: 'vjs-share-menu-open-button vjs-share-menu-top-button',
      type: 'button'
    });

    openShareButton.title = 'Share Video';
    openShareButton.setAttribute('aria-label', 'Share Video');
    openShareButton.innerHTML = '<span class="vjs-icon-share"></span>';
    openShareButton.addEventListener('click', function (e) {
      var playerContainer = player.el();
      var el = playerContainer.querySelector('.vjs-share-menu-lower-container');
      openShareButton.classList.toggle('open');
      el.classList.toggle('show');
      e.stopPropagation();
    });
    openShareButton.addEventListener('touchend', function (e) {
      e.stopPropagation();
    });
    _this.el_ = openShareButton;
    return _this;
  }

  return OpenShareButtonControl;
}(Component$2);

/* eslint-disable no-undef */
var Component$1 = videojs.getComponent('Component');
/**
  * The class for Download Button
  *
  * @extends Component
  */

var ShareMenuButtonsControl = /*#__PURE__*/function (_Component) {
  _inheritsLoose(ShareMenuButtonsControl, _Component);

  /**
   * Constructor for class
   *
   * @param {Player|Object} player The player
   * @param {options|Object} options player options
   */
  function ShareMenuButtonsControl(player, options) {
    var _this;

    _this = _Component.call(this, player, options) || this;

    var menu = _this.createEl('div', {
      className: 'vjs-share-menu-lower-container'
    });

    menu.addEventListener('touchend', function (e) {
      e.stopPropagation();
    }); // load icons into menu

    for (var i = 0; i < options.shareTypes.length; i++) {
      ShareMenuButtonsControl.createSocialButtons(options.shareTypes[i], player, menu);
    } // hide menu when player is clicked


    var documentEl = videojs.browser.IS_FIREFOX ? document.documentElement : document;
    player.on(documentEl, ['click', 'tap'], function (e) {
      var menuEl = document.querySelector('.vjs-share-menu-lower-container');
      menuEl.classList.remove('show');
    });
    _this.el_ = menu;
    return _this;
  }
  /**
  * createSocialButtons
  *
  * @param {shareType|Object} shareType object containing data for share link
  * @param {player|Object} player player
  * @param {menu|Object} menu menu
  */


  ShareMenuButtonsControl.createSocialButtons = function createSocialButtons(shareType, player, menu) {
    shareType.type = shareType.type.toLowerCase();
    var shareButton = new Component$1(player).createEl('button', {
      className: 'vjs-share-button vjs-icon-' + shareType.type,
      title: shareType.type,
      type: 'button'
    });
    var shareUrl = '';

    switch (shareType.type) {
      case 'twitter':
        shareUrl = 'https://twitter.com/intent/tweet?url=' + shareType.url;

        if (typeof shareType.text !== 'undefined') {
          shareUrl += '&text=' + shareType.text;
        }

        if (typeof shareType.hashtags !== 'undefined') {
          shareUrl += '&hashtags=' + shareType.hashtags;
        }

        break;

      case 'linkedin':
        shareUrl = 'https://www.linkedin.com/shareArticle?mini=true&url=' + shareType.url;

        if (typeof shareType.title !== 'undefined') {
          shareUrl += '&title=' + shareType.title;
        }

        if (typeof shareType.summary !== 'undefined') {
          shareUrl += '&summary=' + shareType.summary;
        }

        break;

      case 'facebook':
        shareUrl = 'http://www.facebook.com/sharer.php?u=' + shareType.url;

        if (typeof shareType.title !== 'undefined') {
          shareUrl += '&title=' + shareType.title;
        }

        if (typeof shareType.description !== 'undefined') {
          shareUrl += '&description=' + shareType.description;
        }

        break;

      default:
        {
          shareUrl = shareType.url;
          break;
        }
    }

    shareButton.addEventListener('click', function () {
      window.open(shareUrl);
      player.pause();
    });
    menu.appendChild(shareButton);
  };

  return ShareMenuButtonsControl;
}(Component$1);

var Component = videojs$1.getComponent('Component');

var defaults = {}; // Cross-compatibility for Video.js 5 and 6.

var registerPlugin = videojs$1.registerPlugin || videojs$1.plugin; // const dom = videojs.dom || videojs;

/**
 * Function to invoke when the player is ready.
 *
 * This is a great place for your plugin to initialize itself. When this
 * function is called, the player will have its DOM and child components
 * in place.
 *
 * @function onPlayerReady
 * @param    {Player} player
 *           A Video.js player object.
 *
 * @param    {Object} [options={}]
 *           A plain object containing options for the plugin.
 */

var onPlayerReady = function onPlayerReady(player, options) {
  if (!options.shareTypes && !options.downloadButton) {
    return;
  }

  if (player.el().classList.contains('vjs-share-menu')) {
    var playerEl = player.el(); // clear the container

    var parent = playerEl.querySelector('.vjs-share-menu-container');
    parent.remove();
  } else {
    // first load
    player.addClass('vjs-share-menu');
  }

  var containerComponent = new Component(player);
  containerComponent.addClass('vjs-share-menu-container');
  var topMenuComponent = new Component(player);
  topMenuComponent.addClass('vjs-share-menu-top-container');

  if (options.shareTypes) {
    topMenuComponent.addChild(new OpenShareButtonControl(player, options));
  }

  if (options.downloadButton) {
    topMenuComponent.addChild(new DownloadButtonControl(player, options));
  }

  containerComponent.addChild(topMenuComponent);

  if (options.shareTypes) {
    containerComponent.addChild(new ShareMenuButtonsControl(player, options));
  }

  player.addChild(containerComponent);
};
/**
 * A video.js plugin.
 *
 * In the plugin function, the value of `this` is a video.js `Player`
 * instance. You cannot rely on the player being in a "ready" state here,
 * depending on how the plugin is invoked. This may or may not be important
 * to you; if not, remove the wait for "ready"!
 *
 * @function shareMenu
 * @param    {Object} [options={}]
 *           An object of options left to the plugin author to define.
 */


var shareMenu = function shareMenu(options) {
  var _this = this;

  this.ready(function () {
    onPlayerReady(_this, videojs$1.mergeOptions(defaults, options));
  });
}; // Register the plugin with video.js.


registerPlugin('shareMenu', shareMenu); // Include the version number.

shareMenu.VERSION = version;

export default shareMenu;
