/* eslint-disable no-undef */
const Component = videojs.getComponent('Component');

/**
  * The class for Download Button
  *
  * @extends Component
  */
class DownloadButtonControl extends Component {
  /**
   * Constructor for class
   *
   * @param {Player|Object} player The player
   * @param {options|Object} options player options
   */
  constructor(player, options) {
    super(player, options);

    if (!options.downloadButton) {
      return;
    }

    if (options.downloadButton.showDownloadButton !== true) {
      return;
    }

    if (options.downloadButton.downloadLink === 'undefined') {
      return;
    }

    const downloadButton = this.createEl('button', {
      className: 'vjs-share-menu-download-button vjs-share-menu-top-button',
      type: 'button'
    });

    downloadButton.setAttribute('title', 'Download Transcript');
    downloadButton.setAttribute('aria-label', 'Download Transcript');
    downloadButton.innerHTML = '<span class="vjs-icon-downloadfile"></span>';

    let downloadTitle = 'Download';

    if (options.downloadButton.downloadTitle !== 'undefined') {
      downloadTitle = options.downloadButton.downloadTitle;
    }

    downloadButton.addEventListener('click', (e) => {
      window.open(options.downloadButton.downloadLink, '_blank');
      player.trigger('transcript', {id: options.downloadButton.id});
      e.stopPropagation();
    });

    downloadButton.addEventListener('touchend', (e) => {
      e.stopPropagation();
    });

    this.el_ = downloadButton;
  }
}

export default DownloadButtonControl;
