/* eslint-disable no-undef */
const Component = videojs.getComponent('Component');

/**
  * The class for Download Button
  *
  * @extends Component
  */
class ShareMenuButtonsControl extends Component {
  /**
   * Constructor for class
   *
   * @param {Player|Object} player The player
   * @param {options|Object} options player options
   */
  constructor(player, options) {
    super(player, options);

    const menu = this.createEl('div', {
      className: 'vjs-share-menu-lower-container'
    });

    menu.addEventListener('touchend', (e) => {
      e.stopPropagation();
    });

    // load icons into menu
    for (let i = 0; i < options.shareTypes.length; i++) {
      ShareMenuButtonsControl.createSocialButtons(options.shareTypes[i], player, menu);
    }

    // hide menu when player is clicked
    const documentEl = videojs.browser.IS_FIREFOX ? document.documentElement : document;

    player.on(documentEl, ['click', 'tap'], function(e) {
      const menuEl = document.querySelector('.vjs-share-menu-lower-container');

      menuEl.classList.remove('show');
    });

    this.el_ = menu;
  }

  /**
 * createSocialButtons
 *
 * @param {shareType|Object} shareType object containing data for share link
 * @param {player|Object} player player
 * @param {menu|Object} menu menu
 */
  static createSocialButtons(shareType, player, menu) {

    shareType.type = shareType.type.toLowerCase();

    const shareButton = new Component(player).createEl('button', {
      className: 'vjs-share-button vjs-icon-' + shareType.type,
      title: shareType.type,
      type: 'button'
    });

    let shareUrl = '';

    switch (shareType.type) {

    case 'twitter':
      shareUrl = 'https://twitter.com/intent/tweet?url=' + shareType.url;

      if (typeof shareType.text !== 'undefined') {
        shareUrl += '&text=' + shareType.text;
      }

      if (typeof shareType.hashtags !== 'undefined') {
        shareUrl += '&hashtags=' + shareType.hashtags;
      }

      break;

    case 'linkedin':
      shareUrl = 'https://www.linkedin.com/shareArticle?mini=true&url=' + shareType.url;

      if (typeof shareType.title !== 'undefined') {
        shareUrl += '&title=' + shareType.title;
      }

      if (typeof shareType.summary !== 'undefined') {
        shareUrl += '&summary=' + shareType.summary;
      }

      break;

    case 'facebook':
      shareUrl = 'http://www.facebook.com/sharer.php?u=' + shareType.url;

      if (typeof shareType.title !== 'undefined') {
        shareUrl += '&title=' + shareType.title;
      }

      if (typeof shareType.description !== 'undefined') {
        shareUrl += '&description=' + shareType.description;
      }

      break;

    default: {
      shareUrl = shareType.url;
      break;
    }

    }

    shareButton.addEventListener('click', () => {
      window.open(shareUrl);
      player.pause();
    });

    menu.appendChild(shareButton);
  }

}

export default ShareMenuButtonsControl;
